<?php
/**
 * Plugin Name: Subtotal
 * Plugin URI: https://subtotal.ru/support/integraczii/integracziya-s-internet-magazinom-woocommerce
 * Description: Subtotal integration with WooCommerce
 * Author: Subtotal
 * Author URI: https://subtotal.ru
 */
require_once 'subtotal-api.php';

/**
 * Проверить запрос пользователя на logout и, если да, разлогинить.
 */
function request_logout()
{
	if (isset($_GET['exit']) && $_GET['exit']) {
		update_option('subtotal_access', false);
		header('Location: ?page=Subtotal');
		wp_die();
	}
}

/**
 * Проверка запроса пользователя на вход в систему
 * Заодно, что не очевидно из названия процедуры, заполняются/проверяются
 * некоторые переменные, например API URL Subtotal.
 * @return bool True, если пользователь пытается войти в систему. Иначе false
 */
function request_login(): bool
{
	if (empty($_POST['subtotal_api_url'])) {
		$_POST['subtotal_api_url'] = SUBTOTAL_API_URL_DEFAULT;
	}

	/**
	 * Завершающий слеш обязателен.
	 * Тупо проверяется последний символ URL'а.
	 * На этом проверки заканчиваются: ответственность за ввод URL'а лежит
	 * на пользователе. Какой ввёл, такой и используется. Почти такой.
	 */
	if (substr($_POST['subtotal_api_url'], -1) !== '/') {
		$_POST['subtotal_api_url'] .= '/';
	}

	$result = false;
	if (
		isset($_POST['subtotal_email'])
		&& isset($_POST['subtotal_password'])
		&& isset($_POST['subtotal_api_url'])
	) {
		$result = true;
	}
	return $result;
}

/**
 * Процедура принимает сессию (по сути имя куки session)
 * и ответ авторизационного запроса к Subtotal API.
 * Если ок, то пользователь авторизуется в WC.
 * Под авторизацией пользователя в WC понимается заполнение опций
 * Статусы в ответе:
 * 	0 - ок;
 * 	1 - внутренняя ошибка;
 * 	2 - пользователь неавторизован.
 */
function check_auth($session, $response): NamedStatus
{
	$result = new NamedStatus();
	try {
		$profile = json_decode($response['body'], true);
	} catch (Throwable $e) {
		update_option('subtotal_access', false);
		$result->message = '<div class="error">';
		$result->message .= 'Внутренняя ошибка. Отправьте код ниже в техническую поддержку Subtotal:';
		$result->message .= '<br><pre>' . $e->getMessage() . '</pre>';
		$result->message .= '</div>';
		$result->status = 1;
		return $result;
	}

	$status = null;
	if (isset($profile['status'])) {
		try {
			$status = intval($profile['status'], 10);
		} catch (Exception $e) {
		}
	}

	if ($session && $status == 200) {
		$owner_id = $profile['last_owner_id'];
		$owner_url = $profile['last_owner'];
		$result->status = 0;
		$result->message = '<div class="process">Авторизация прошла успешно</div>';
		$subtotal_access = [
			'session' => $session,
			'owner_id' => $owner_id,
			'owner_url' => $owner_url,
			'login' => $_POST['subtotal_email'],
		];
		update_option('subtotal_access', json_encode($subtotal_access));
		update_option('subtotal_owner_id', $owner_id);
		update_option('subtotal_owner_url', $owner_url);
		/**
		 * Логика такова, что при успешной авторизации из Subtotal
		 * считываются какие-то данные. В данном случае - теги.
		 * TODO: что с другими данными?
		 */
		update_option('subtotal_good_tags', json_encode(st_getGoodTags()));
	} else {
		// А вот статусы могут быть не только 401. Но их обработка потом...
		update_option('subtotal_access', false);
		$result->status = 2;
		$result->message = '<div class="error">Неправильный логин/пароль</div>';
	}

	return $result;
}
?>

<style type="text/css">
	.subtotal .error {
		border: 1px solid red;
		padding: 10px;
		color: red;
		margin-top: 10px;
	}

	.subtotal .process {
		border: 1px solid green;
		padding: 10px;
		color: green;
		margin-top: 10px;
	}

	#toplevel_page_Subtotal .wp-menu-image img {
		opacity: 1 !important;
		padding-top: 6px;
	}

	.form-table td>input {
		width: 20%;

	}
</style>
<div class="wrap subtotal">

	<h2>Обмен с Subtotal (beta v<?php echo $csver;?>)</h2>

	<?php

request_logout();

if (request_login()) {
	// Если поля формы аутентификации заполнены,
	// то URL Subtotal API сохраняется, затирая существующий.
	update_option('subtotal_api_url', $_POST['subtotal_api_url']);

	$auth_response = st_Authentication(
		$_POST['subtotal_email'],
		$_POST['subtotal_password'],
		$_POST['subtotal_api_url']
	);

	if (!$auth_response->status) {
		$auth_result = check_auth($auth_response->data, $auth_response->response);
		echo $auth_result->message;
	} else {
		echo $auth_response->message;
	}
}

if (get_option('subtotal_access')) { // УЖОС!!!!!
	include 'import-page.php';
} else {
	include 'login-page.php';
}
?>

</div>