<?php
/**
 * Plugin Name: Subtotal
 * Plugin URI: https://subtotal.ru/support/integraczii/integracziya-s-internet-magazinom-woocommerce
 * Description: Subtotal integration with WooCommerce
 * Author: Subtotal
 * Author URI: https://subtotal.ru
 */
require_once 'sublogic/sync.php';
require_once 'sublogic/subtotal-api.php';
require_once 'sublogic/functions.php';

/**
 * Театр начинается с вешалки, а логика синхронизации - с инициализации.
 * Если разрастётся можно вынести в отдельную процедуру.
 */
$block_ttl = get_option('subtotal_block_ttl');
if ( !isset($block_ttl) || !is_integer($block_ttl) ) {
	update_option('subtotal_block_ttl', BLOCK_TTL);
}

$cron_update_period = get_option('subtotal_cron_update_period');
if ( !isset($cron_update_period) || !is_integer($cron_update_period) ) {
	update_option('subtotal_cron_update_period', CRON_UPDATE_PERIOD);
}



add_action('admin_menu', 'subtotal_menu');

/**
 * Добавляет пункт меню Subtotal в WordPress
 */
function subtotal_menu()
{
	add_menu_page(
		'Subtotal',
		'Subtotal',
		'manage_options',
		'Subtotal',
		'showSubtotal',
		plugin_dir_url(__FILE__) . 'icon.png',
		56
	);
}

/**
 * Вызывается когда пользователь выбирает Subtotal в боковом меню
 */
function showSubtotal()
{
	$csver = 0.16;
	require_once 'sublogic/main.php';
}

/** Хук на получение количество товаров */
add_action('wp_ajax_st_getCatalogCount', 'st_getCatalogCount_callback');
/** Хук на запуск импорта категорий */
add_action('wp_ajax_st_importGoodTags', 'st_importGoodTags_callback');
/** Хук за запуск импорта продуктов */
add_action('wp_ajax_st_importProducts', 'st_importProducts_callback');
/** Хук на обновление статуса заказа */
add_action('woocommerce_update_order', 'subtotal_export');

/** Действие по расписанию - фоновое обновление товаров */
add_filter('cron_schedules', 'subtotal_cron_interval');

/**
 * Хуки на чтение опций синхронизации Subtotal
 */
add_filter('option_subtotal_access', 'json_assoc');
add_filter('option_subtotal_api_url', 'check_subtotal_url');
add_filter('option_subtotal_block_ttl', 'force_int');
add_filter('option_subtotal_import_good_tags', 'json_array');
add_filter('option_subtotal_import_limit_value', 'force_int');
add_filter('option_subtotal_import_photos', 'force_bool');
add_filter('option_subtotal_import_pos', 'force_int');
add_filter('option_subtotal_import_price', 'force_int');
add_filter('option_subtotal_import_stores', 'force_int_keys');
add_filter('option_subtotal_last_import_timestamp', 'force_int');
add_filter('option_subtotal_cron_update_period', 'force_int');
add_filter('option_subtotal_update_stocks', 'force_bool');

/**
 * Процедура для установления расписания Subtotal в WordPress
 */
function subtotal_cron_interval($schedules)
{
	$interval = get_option('subtotal_cron_update_period');

	if (!isset($interval) || !is_int($interval)) {
		$interval = CRON_UPDATE_PERIOD;
	}

	// В секунды
	$interval = $interval * 60;

	$schedules['subtotal_seconds'] = [
		'interval' => $interval,
		'display' => esc_html__('Subtotal Specified Seconds'),
	];
	return $schedules;
}

/** Действие по расписанию */
add_action('subtotal_cron_hook', 'subtotal_cron_exec');

/** Если не запланировано - запланировать */
if (!wp_next_scheduled('subtotal_cron_hook')) {
	wp_schedule_event(time(), 'subtotal_seconds', 'subtotal_cron_hook');
}
